clear
close all
clc

DIM   =   60;   %  TRANSITION LENGTH
Year   =   2020:+10:2020+(DIM-1)*10;

% % %  -------------------------- USE COAL TAXES --------------------------
% % %  -------------------------- USE COAL TAXES --------------------------
% % %  -------------------------- USE COAL TAXES --------------------------

% % % ----------------- SET REGIME AND ELASTICITY -------------------------
Tax_dum   =   1;
% % % CO2 TAXES IN ALL COUNTRIES: Tax_dum   =   1;
% % % COAL TAXES IN ALL COUNTRIES: Tax_dum   =   2;



% % % --------------------- TYPE 1 AND 2 ERRORS ---------------------------
% % % --------------------- TYPE 1 AND 2 ERRORS ---------------------------
% % % --------------------- TYPE 1 AND 2 ERRORS ---------------------------
% % % TYPE 1 AND 2 ERRORS ARE COMPUTED FOR BOTH THE BENCHMARK ELASTICITY OF
% 0.95 AND FOR A HIGHER ELASTICITY. FIRST SOLVE THE MODEL FOR THE BENCHMARK
% VALUE. THEN RUN THE EXPERIMENT AGAIN WITH THE HIGHER ELASTICITY

% LOW CLIMATE, LOW ECONOMIC; LOW CLIMATE, HIGH ECONOMIC;
% HIGH CLIMATE, LOW ECONOMIC; HIGH CLIMATE, HIGH ECONOMIC;


% % % --------------------------- PARAMETERS ------------------------------
BM_elast   =   0.95;   % Bennchmark elasticity of substitution between green and brown
elast   =   BM_elast;   % Elasticity of substitution between green and brown

% elast   =   1.25;   % Elasticity of substitution between green and brown


rho     =   (elast-1)/elast;

alpha   =   0.3;        % Capital share
beta    =   0.985^10;   % Discount factor
nu      =   0.05;      % Energy share

% -------------------------- FOR THE OIL COMPOSITE ------------------------
elast_h   =  10;
rho_h     =   (elast_h-1)/elast_h;


Oil_weight   =   0.995;




% --------------- OIL EXTRACTION THAT DIRECTLY GENERATE EMISSIONS ---------
Supply_emiss   =  0.32;

% % % ----------------------- CLIMATE PARAMETERS --------------------------
% % % ----------------------- CLIMATE PARAMETERS --------------------------
% % % ----------------------- CLIMATE PARAMETERS --------------------------

lambda_1   =   0.54289;
lambda_2   =   0.187*lambda_1;
lambda_3   =   0.655*lambda_1;

S_preind   =   581; % MEASURED IN GtC
S0         =   800;
T_0        =   0.85;
TL_0       =   0.01;

% % % ---------------------------- DAMAGES --------------------------------
% % % ---------------------------- DAMAGES --------------------------------
% % % ---------------------------- DAMAGES --------------------------------

eta   =   3.7;
lambda   =   3;
Sigma1   =   0.22;
Sigma2   =   0.3;
Sigma3   =   0.05;

% % % ------- BENCHMARK -------
psi    =   0.0228; % 0.0228
psiL   =   0.2;    % 0.2
psi0   =   0.393;  % 0.393
% % % BENCHMARK: psi = 0.0228; psiL = 0.2; psi0 = 0.393;


% % % ----------------------- INTITAL CONDITIONS --------------------------
% % % ----------------------- INTITAL CONDITIONS --------------------------
% % % ----------------------- INTITAL CONDITIONS --------------------------

% % ---------------------------- CAPITAL --------------------------------
% K_0_Glob = 39.2*5;
K_0_Glob = 190;


% % ---------------------------- TFP --------------------------------
% % ---------------- SET Glob_TFP TO MATCH WORLD GDP
Glob_TFP           =   2.8;
% % % Initial_prod_Glob = Glob_TFP*55.5;
Initial_prod_Glob = 143;


Prod_growth             =   1.015^10;

% % --------------------------- PRICES ----------------------------------
% % % % ------  USE GREEN PRICES TO CALIBRATE THE MODEL -----------------
Green_price_Init     = 600;
Green_price_Init_Glob = Green_price_Init;

% % -------------------- CARBON CONTENT ---------------------------------
Carbon_content_oil    =   84.6/100;
Carbon_content_coal   =   71.6/100;

C_price                     =   74;
Coal_price_global_p_ton_C =   C_price/Carbon_content_coal;
Coal_price_Init_Glob =   C_price/Carbon_content_coal;

Growth_factor_oil_subst    =  1;
% % -------------------------- FRACKING ---------------------------------
% % FROM THE EIA: The U.S. Energy Information Administration (EIA) estimates that in 2018,
% % about 6.5 million barrels per day of crude oil were produced directly from
% % tight oil resources in the United States. This was equal to about 59 percent
% % of total U.S. crude oil production in 2018.

Oil_subst_price_Init_Glob     =   347;

OIL_Glob = ones(4,DIM);

COAL_Glob = ones(4,DIM);

GREEN_Glob = ones(4,DIM);

ENERGY_COMP_Glob = ones(4,DIM);


% % % -------------------------- AGGREGATES -------------------------------
% % % -------------------------- AGGREGATES -------------------------------
% % % -------------------------- AGGREGATES -------------------------------
S               =   S0*ones(DIM,1);
S2              =   ones(DIM,1);
S1_S_Bar        =   ones(DIM,1);
Temp            =   T_0*ones(DIM,1);
Temp_L          =   TL_0*ones(DIM,1);
Forcing         =   ones(DIM,1);
Global_Damage   =   ones(DIM,1);

Oil_Use_Agg           =   ones(DIM,1);
Coal_Use_Agg          =   ones(DIM,1);
Green_Use_Agg         =   ones(DIM,1);
Emissions_Oil_Count   =   ones(DIM,1);
Emissions_Agg         =   ones(DIM,1);

GROSS_OUT_Yearly_Agg        =   ones(DIM,1);
GDP_Yearly_Agg              =   ones(DIM,1);

% % % ---------------- VARY THE WRONG TAX OF UNDERESTIMATING CC -----------
% % % --------------- NOTE THAT COSTS AND TAXES ARE PROPORTIONAL ----------
% % % -UPPER GAMMA IS 3.44 AND THE CORRESPONDING CORRECT TAX IS 0.768*3.44-
GAMMA   =   [0.0894;3.44];

CONS_Glob     =   zeros(4,DIM);
OUTPUT_Glob   =   zeros(4,DIM);
CONS_OP     =   zeros(4,DIM);


for gamma_dum=1:length(GAMMA)
    
    t_loop = 2;
    
    for taxes=1:t_loop
        % % % ------------- LOOP OVER CORRECT AND INCORRECT TAX RATES -------------
        % % % ------------- LOOP OVER CORRECT AND INCORRECT TAX RATES -------------
        % % % ------------- LOOP OVER CORRECT AND INCORRECT TAX RATES -------------
        
        IND   =  taxes + 2*(gamma_dum-1);
        
        % % % IND   =  1: LOW TAX WHEN LOW TAX IS CORRECT
        % % % IND   =  2: HIGH TAX WHEN LOW TAX IS CORRECT
        % % % IND   =  3: LOW TAX WHEN HIGH TAX IS CORRECT
        % % % IND   =  4: HIGH TAX WHEN HIGH TAX IS CORRECT
        
        
        % % % -------------------------- TAX RATE -------------------------
        % % % -------------------------- TAX RATE -------------------------
        % % % -------------------------- TAX RATE -------------------------
        
        Tax_carbon   =   0.0768*GAMMA(taxes);
        
        Growth_tax_rate   =   1.022^10;
          
        [Tax_rate_Coal_Glob,Tax_rate_Oil_Glob,Tax_rate_Frack_Glob] =  Tax_regimes_One_Region(Tax_dum);
        

% % %   ---------------- RULE OUT FRACKING HERE -----------
        Tax_rate_Frack_Glob   =   1000; 
       
        
        
        gamma_global   =   (3.21e-5)*GAMMA(gamma_dum);
        gamma_Glob       =   gamma_global;
        
        
        
        Capgamma   =   gamma_global*(psiL/(1-beta)+(1-psiL)*psi0/(1-(1-psi)*beta));
        xi         =   1;
        
        R0         =   300*Carbon_content_oil; 
        
        % % %   THE SAVINGS RATE OF NET OUTPUT
        
        saving_rate   =   alpha*beta/(1-nu);
        
        
        % % % % % % -------------------- GUESS ON THE OIL PRICE -----------------
            % % % % % % -------------------- GUESS ON THE OIL PRICE -----------------
        % % % % % % -------------------- GUESS ON THE OIL PRICE -----------------
        
        Oil_Price   =  ones(DIM,1);
        
        % % % ----------- FIND THE OIL PRICE FOR EACH t WITH BISECTION ------------
        Oil_Price_min_1   =   ones(DIM,1);
        Oil_Price_max_1   =   ones(DIM,1);
        
        Oil_Price_min   =   0;
        Oil_Price_max   =   1;
        
        % % % --------------- CHECK SO THAT THE SOLUTION IS INTERIOR --------------
        Oil_Price_min_1(1)   =   Oil_Price_min;
        Oil_Price_max_1(1)   =   Oil_Price_max;
        
        Oil_Price(1)   =   (Oil_Price_min + Oil_Price_max)/2;
        
        Oil_Reserves   =   R0*ones(DIM,1);
        Oil_Supply   =     ones(DIM,1);
        for i   =   1:DIM
            Oil_Supply(i,1)   =   (1-beta)*Oil_Reserves(i);
            Oil_Reserves(i+1,1)   =   Oil_Reserves(i)-Oil_Supply(i,1);
        end
        
        Productivity_Glob    =   (Initial_prod_Glob*Prod_growth.^(0:DIM-1))';
                
         
        % % % ----------------- PREDEFINE VARIABLES -------------------
        % % % ----------------- PREDEFINE VARIABLES -------------------
        % % % ----------------- PREDEFINE VARIABLES -------------------
        Damage_Glob               =   ones(DIM,1);
        Capital_Glob              =   K_0_Glob*ones(DIM,1);
        
        MPK_Glob              =   K_0_Glob*ones(DIM,1);
        
        Cons_Oil_Producers      =   ones(DIM,1);
        
        Tax_Oil_Glob              =   ones(DIM,1);
        Coal_Price_Glob           =   ones(DIM,1);
        Tax_Coal_Glob             =   ones(DIM,1);
        Green_Price_Glob          =   ones(DIM,1);
        Tax_Green_Glob            =   ones(DIM,1);
        Energy_Price_Glob         =   ones(DIM,1);
        Energy_Services_Glob      =   ones(DIM,1);
        Oil_Use_Glob              =   ones(DIM,1);
        Coal_Use_Glob             =   ones(DIM,1);
        Green_Use_Glob            =   ones(DIM,1);
        Gross_Output_Glob         =   ones(DIM,1);
        GDP_Glob                  =   ones(DIM,1);
        
        % % % ----------- FRACKING --------------
        Oil_subst_Use_Glob        =   ones(DIM,1);        
        Oil_subst_Price_Glob      =   ones(DIM,1);
        
        Oil_comp_Price_Glob       =   ones(DIM,1);
        Oil_comp_Use_Glob         =   ones(DIM,1);
               
        Tax_Oil_subst_Glob        =   ones(DIM,1);
        
        Fracking_Agg                =   ones(DIM,1);
        
   
        Net_Output_Inc_tax_Glob    =   ones(DIM,1);
           
        Consuption_Yearly_Glob    =   ones(DIM,1);
                        
        Coal_Price_Glob(1)       =   Coal_price_Init_Glob/1000;
                
        Green_Price_Glob(1)       =   Green_price_Init_Glob/1000;
        
        Oil_subst_Price_Glob(1)   =   Oil_subst_price_Init_Glob/1000;
        
        for t=1:DIM
            
            % % % ---------------------- ITERATE OVER THE OIL PRICE -------------------
            diff_oil_p   =   10;
            Oil_Price_old   =   Oil_Price(t);
            while diff_oil_p>1e-8
                
                
                % % % ------------------------------ US -----------------------------------
                % % % ------------------------------ US -----------------------------------
                % % % ------------------------------ US -----------------------------------
                Damage_Glob(t)              =   1 - exp(-gamma_Glob*(S(t)-S_preind));
                Tax_Oil_Glob(t)             =   Tax_carbon*Tax_rate_Oil_Glob*(Growth_tax_rate^(t-1));
                Coal_Price_Glob(t+1)        =   Coal_Price_Glob(t);
                Tax_Coal_Glob(t)            =   Tax_carbon*Tax_rate_Coal_Glob*(Growth_tax_rate^(t-1));
                Green_Price_Glob(t+1)       =   Green_Price_Glob(t);
                Tax_Green_Glob(t)           =   0;
                Oil_subst_Price_Glob(t+1)   =   Oil_subst_Price_Glob(t);
                
                Tax_Oil_subst_Glob(t)     =   Tax_carbon*Tax_rate_Frack_Glob*(Growth_tax_rate^(t-1));
                
                Oil_comp_Price_Glob(t) = (1/2)*(Oil_weight^(1/(1-rho_h))*(Oil_Price(t)+Tax_Oil_Glob(t))^(rho_h/(rho_h-1))+(1-Oil_weight)^(1/(1-rho_h))*(Oil_subst_Price_Glob(t)+Tax_Oil_subst_Glob(t))^(rho_h/(rho_h-1)))^((rho_h-1)/rho_h);
                
                
                Energy_Price_Glob(t)     =   ((Oil_comp_Price_Glob(t))^(rho/(rho-1))*lambda_1^(1/(1-rho)) +(Coal_Price_Glob(t)+Tax_Coal_Glob(t))^(rho/(rho-1))*lambda_2^(1/(1-rho))+...
                    (Green_Price_Glob(t)+Tax_Green_Glob(t))^(rho/(rho-1))*lambda_3^(1/(1-rho)))^((rho-1)/rho);
                
                Energy_Services_Glob(t)  =   (nu*Productivity_Glob(t)*(1-Damage_Glob(t))*(Capital_Glob(t)^alpha)/Energy_Price_Glob(t))^(1/(1-nu));
                
                Coal_Use_Glob(t)         =   Energy_Services_Glob(t)*(Energy_Price_Glob(t)*lambda_2/(Coal_Price_Glob(t)+Tax_Coal_Glob(t)))^(1/(1-rho));
                Green_Use_Glob(t)        =   Energy_Services_Glob(t)*(Energy_Price_Glob(t)*lambda_3/(Green_Price_Glob(t)+Tax_Green_Glob(t)))^(1/(1-rho));
                Oil_comp_Use_Glob(t)     =   Energy_Services_Glob(t)*(Energy_Price_Glob(t)*lambda_1/(Oil_comp_Price_Glob(t)))^(1/(1-rho));
                
                % % %                   Oil_Use_Glob(t)          =   Energy_Services_Glob(t)*(Energy_Price_Glob(t)*lambda_1/(Oil_Price(t)+Tax_Oil_Glob(t)))^(1/(1-rho));
                Oil_Use_Glob(t)          =   Oil_comp_Use_Glob(t)*(2^(rho_h/(1-rho_h)))*((Oil_weight*Oil_comp_Price_Glob(t)/(Oil_Price(t)+Tax_Oil_Glob(t)))^(1/(1-rho_h)));
                
                Oil_subst_Use_Glob(t)    =   Oil_comp_Use_Glob(t)*(2^(rho_h/(1-rho_h)))*(((1-Oil_weight)*Oil_comp_Price_Glob(t)/(Oil_subst_Price_Glob(t)+Tax_Oil_subst_Glob(t)))^(1/(1-rho_h)));
                
                Gross_Output_Glob(t)           =   Productivity_Glob(t)*(1-Damage_Glob(t))*(Capital_Glob(t)^alpha)*(Energy_Services_Glob(t)^nu);
                GDP_Glob(t)                    =   Gross_Output_Glob(t)-Oil_Price(t)*Oil_Use_Glob(t);
                Net_Output_Inc_tax_Glob(t)     =   (1-nu)*Gross_Output_Glob(t)+Tax_Oil_Glob(t)*Oil_Use_Glob(t)+Tax_Coal_Glob(t)*Coal_Use_Glob(t)+Tax_Green_Glob(t)*Green_Use_Glob(t) + Tax_Oil_subst_Glob(t)*Oil_subst_Use_Glob(t);
                Capital_Glob(t+1)              =   saving_rate*Net_Output_Inc_tax_Glob(t);
                MPK_Glob(t)                    =   alpha*Gross_Output_Glob(t)/Capital_Glob(t);
                Consuption_Yearly_Glob(t)      =   Net_Output_Inc_tax_Glob(t)*(1-alpha*beta)/10;
                
                
                % % % ----------------------- OIL PRODUCERS -------------------------------
                % % % ----------------------- OIL PRODUCERS -------------------------------
                % % % ----------------------- OIL PRODUCERS -------------------------------
                Cons_Oil_Producers(t)   =   Oil_Price(t)*Oil_Supply(t);
                
                Emissions_Oil_Count(t)   =   Supply_emiss*Oil_Supply(t);
                
                Oil_Use_Agg(t)   =   Oil_Use_Glob(t);
                
                % % % ----------------------- UPDATE THE OIL PRICE ------------------------
                % % % ----------------------- UPDATE THE OIL PRICE ------------------------
                % % % ----------------------- UPDATE THE OIL PRICE ------------------------
                if Oil_Use_Agg(t)>Oil_Supply(t)
                    Oil_Price_min   =   Oil_Price(t);
                else
                    Oil_Price_max   =   Oil_Price(t);
                end
                
                Oil_Price(t)   =   (Oil_Price_min + Oil_Price_max)/2;
                
                diff_oil_p   =   abs(Oil_Price(t)-Oil_Price_old);
                
                Oil_Price_old   =   Oil_Price(t);
            end
            
            if (Oil_Price(t)==Oil_Price_min_1(t)) || (Oil_Price(t)==Oil_Price_max_1(t))
                disp('WARNING!!! BOUNDARY HIT!!!')
            end
            
            % % % ---------------------- AGGREGATE QUANTITIES -------------------------
            % % % ---------------------- AGGREGATE QUANTITIES -------------------------
            % % % ---------------------- AGGREGATE QUANTITIES -------------------------
            
            Coal_Use_Agg(t)          =   Coal_Use_Glob(t);
            Green_Use_Agg(t)         =   Green_Use_Glob(t);
            Fracking_Agg(t)          =   Oil_subst_Use_Glob(t);
            GROSS_OUT_Yearly_Agg(t)  =   Gross_Output_Glob(t)/10;
            GDP_Yearly_Agg(t)        =   GDP_Glob(t)/10;
            
            Emissions_Agg(t)      =   Oil_Supply(t) + Coal_Use_Agg(t) + Fracking_Agg(t)  + Emissions_Oil_Count(t);
            
            % % % ------------------ CO2, TEMPERATURE AND FORCING ---------------------
            Global_Damage(t)   =   1-exp(-gamma_global*(S(t)-S_preind));
            
            Oil_Price_Barrel   =   Oil_Price*(1000/7.33)*Carbon_content_oil;
            
            if t==1
                S2(t)      =   (699-S_preind)*(1-psi)+psi0*(1-psiL)*(Emissions_Agg(1));
                S1_S_Bar(t)   =   103+psiL*(Emissions_Agg(t));
            else
                S2(t)      =   (S2(t-1))*(1-psi)+psi0*(1-psiL)*(Emissions_Agg(t));
                S1_S_Bar(t)   =   S1_S_Bar(t-1)+psiL*(Emissions_Agg(t));
            end
            
            S(t+1)         =   S2(t)+S1_S_Bar(t)+S_preind;
            Forcing(t+1)   =   eta*log(S(t+1)/S_preind)/log(2);
            Temp(t+1)      =   Temp(t)+Sigma1*(Forcing(t+1)-(eta/lambda)*Temp(t)-Sigma2*(Temp(t)-Temp_L(t)));
            Temp_L(t+1)    =   Temp_L(t)+Sigma3*(Temp(t)-Temp_L(t));
            
            % % % ----------------- NEW BOUNDARIES FOR THE OIL PRICE  -----------------
            Oil_Price_min   =   Oil_Price(t)/3;
            Oil_Price_max   =   Oil_Price(t)*3;
            
            Oil_Price_min_1(t+1)   =   Oil_Price_min;
            Oil_Price_max_1(t+1)   =   Oil_Price_max;
            
            Oil_Price(t+1)   =   (Oil_Price_min + Oil_Price_max)/2;
            
        end
        
        
        % % % ------------------- IND=1: LOW GAMMA, CORRECT TAX -------------------
        % % % ------------------- IND=2: LOW GAMMA, INCORRECT TAX -----------------
        % % % ------------------- IND=3: HIGH GAMMA, INCORRECT TAX ------------------
        % % % ------------------- IND=4: HIGH GAMMA, CORRECT TAX ----------------
                
        
        % % %           ------------ SAVE ENERGY USE AND CONSUMPTION
        
        CONS_Glob(IND,:)   =   Consuption_Yearly_Glob';        
        
        OUTPUT_Glob(IND,:)   =   GDP_Glob';        
        
        CONS_OP(IND,:)   =   Cons_Oil_Producers'./10;        
        
        OIL_Glob(IND,:)   =   Oil_Use_Glob';
        
        COAL_Glob(IND,:)   =   Coal_Use_Glob';
        
        GREEN_Glob(IND,:)   =   Green_Use_Glob';
        
        ENERGY_COMP_Glob(IND,:)   =   Energy_Services_Glob';
        
    end
end

% % % --------------------- PLOT CALIBRATION AND OUTPUT -------------------
disp('Annual MPK in period 1')
disp(MPK_Glob(1).^(1/10))
disp(' ')

disp('The initial oil price per barrel is:');disp(Oil_Price_Barrel(1))
disp(' ')

disp('Global GDP in the data in 2017:');disp('   80.14 Trillion U.S. dollars ')
disp(' ')

disp('Global GDP in the model t=1:');disp(GDP_Yearly_Agg(1))
disp(' ')

disp('Capital output ratio per year in t=2:');disp(Capital_Glob(2)/(GDP_Glob(2)/10))
disp(' ')

% % %  SOURCE:CO2_EMISSIONS_TIME_SERIES_WORLD_BANK
CO2_Data = [9396705.84	9434402.6	9818839.87	10355747.3	10947007.1	11433442	12009447	12389685.6	13017193.6	13797116.8	14788798.3	15323175.6	15957192.5	16822109.5	16850822.1	16745791.9	17726098.3	18279804.3	18497906.5	19533547.9	19324327.3	18726246.9	18562354	18484356.9	19145865.4	19719241.2	20315356	20817152	21565403.3	22029385.2	22149402.4	22403928.9	22183417.5	22162174.6	22551690.6	23037524.1	23571556.7	23975007.3	24114192	24059187	24689911	25276631	25646998	27047792	28393581	29490014	30568112	31180501	32181592	31891899	33472376	34847501	35470891	35837591	36138285]./(3.6*1000000);


% % % ------------------- FOR THE PLOTS: Lw - Linewidth -------------------
% % % ------------------- FOR THE PLOTS: Lw - Linewidth -------------------
% % % ------------------- FOR THE PLOTS: Lw - Linewidth -------------------
Lw_1=4;
Lw_2=1;


elast_dum   =  elast;

% % % --------------------- TYPE 1 AND TYPE 2 ERRORS-----------------------
% % % --------------------- TYPE 1 AND TYPE 2 ERRORS-----------------------
% % % --------------------- TYPE 1 AND TYPE 2 ERRORS-----------------------

% % % ---------------------- SAVE BENNCHMARK VALUES------------------------


% % % IND   =  1: LOW TAX WHEN LOW TAX IS CORRECT
% % % IND   =  2: HIGH TAX WHEN LOW TAX IS CORRECT
% % % IND   =  3: LOW TAX WHEN HIGH TAX IS CORRECT
% % % IND   =  4: HIGH TAX WHEN HIGH TAX IS CORRECT

if elast==BM_elast
    
    US_high_tax_BM   =  (1-CONS_Glob(2,1:end)./CONS_Glob(1,1:end))*100;
    US_low_tax_BM   =  (1-CONS_Glob(3,1:end)./CONS_Glob(4,1:end))*100;
    
    OP_high_tax_BM   =  (1-CONS_OP(2,1:end)./CONS_OP(1,1:end))*100;
    OP_low_tax_BM   =  (1-CONS_OP(3,1:end)./CONS_OP(4,1:end))*100;
    
    
    % % % --------------------------- FUELS -------------------------------
    
    % LOW CLIMATE, LOW ECONOMIC; LOW CLIMATE, HIGH ECONOMIC;
    % HIGH CLIMATE, LOW ECONOMIC; HIGH CLIMATE, HIGH ECONOMIC;
    
    US_coal_Underestimate_BM    =  COAL_Glob(3,:);    
    US_coal_Overestimate_BM    =  COAL_Glob(2,:);    
    US_green_Underestimate_BM    =  GREEN_Glob(3,:);    
    US_green_Overestimate_BM    =  GREEN_Glob(2,:);
    
    
    % % % ------------ THE COSTS OF ERROR 1 -------------------
    Cost_low_tax_correct_BM   =   (1-((CONS_Glob(3,1:end)+CONS_OP(3,1:end))./(CONS_Glob(4,1:end)+CONS_OP(4,1:end))))';
    
    % % % ------------ THE COSTS OF ERROR 2 -------------------
    Cost_high_tax_correct_BM   =   (1-(CONS_Glob(2,1:end)+CONS_OP(2,1:end))./(CONS_Glob(1,1:end)+CONS_OP(1,1:end)))';

    
    save BM_elast_One_Region Cost_low_tax_correct_BM Cost_high_tax_correct_BM                
end


% % % ------------------------- TYPE 1 AND 2 ERRORS -----------------------
% % % ------------------------- TYPE 1 AND 2 ERRORS -----------------------
% % % ------------------------- TYPE 1 AND 2 ERRORS -----------------------


load BM_elast_One_Region
     
% % % IND   =  1: LOW TAX WHEN LOW TAX IS CORRECT
% % % IND   =  2: HIGH TAX WHEN LOW TAX IS CORRECT
% % % IND   =  3: LOW TAX WHEN HIGH TAX IS CORRECT
% % % IND   =  4: HIGH TAX WHEN HIGH TAX IS CORRECT


Cost_low_tax_high_is_correct   =   (1-((CONS_Glob(3,1:end)+CONS_OP(3,1:end))./(CONS_Glob(4,1:end)+CONS_OP(4,1:end))))';
Cost_high_tax_low_is_correct   =   (1-((CONS_Glob(2,1:end)+CONS_OP(2,1:end))./(CONS_Glob(1,1:end)+CONS_OP(1,1:end))))';

% % % -------------------------- PLOT EFFECTS -----------------------------


% % % ---------------------- CONSUMPTION LOSSES ---------------------------
All_max    =  max(Cost_low_tax_high_is_correct(1:20)*100);

figure
plot(Year(2:end),Cost_low_tax_high_is_correct(2:end)*100,'k','linewidth',Lw_1)
hold on
plot(Year(2:end),Cost_high_tax_low_is_correct(2:end)*100,'--r','linewidth',Lw_1)
title('Consumption losses ')

% % % - IF ELASTICITY DIFFERS FROM THE BENCHMARK, PLOT ALSO THE BENCHMARK -
if elast~=BM_elast
    hold on
    plot(Year(2:end),Cost_low_tax_correct_BM(2:end)*100,'-.m','linewidth',Lw_1)
    hold on
    plot(Year(2:end),Cost_high_tax_correct_BM(2:end)*100,'o-b','linewidth',Lw_2)
end

ylabel('{\itC} loss in %')
axis([2020 2200 -5 All_max])
grid on

if elast~=BM_elast
    legend([strcat('Too low a tax , \epsilon=',(num2str(elast)));strcat('Too high a tax, \epsilon=',(num2str(elast))); ...
        strcat('Too low a tax , \epsilon=',(num2str(BM_elast))); strcat('Too high a tax, \epsilon=',(num2str(BM_elast)))],'FontSize',10,'location','Northwest')
else
    legend([strcat('Too low a tax , \epsilon=',(num2str(elast)));strcat('Too high a tax, \epsilon=',(num2str(elast)))],'FontSize',10,'location','Northwest')
end
