% % % TYPE 1 AND 2 ERRORS
% % % BY Conny Olovsson

clear
close all
clc


% % % ----------------------- CALIBRATION -----------------------
lambda   =   0.64;

% % % ELAST = 0:   THE BENCHMARK WITH rho      =   -0.058.
% % % ELAST = 1:   A HIGH ELASTICITY OF SUBSTITUTION WITH rho      =   2.
% % % ELAST = 2:   A LOW ELASTICITY OF SUBSTITUTION WITH rho       =   0.5.
ELAST   =   0;

if ELAST==0
    rho      =   -0.058;
elseif ELAST==1
    rho      =   0.5;
elseif ELAST==2
    rho      =   -1;
end

nu       =   0.031;
p1       =   1;
p2       =   p1*5.87;

if rho==-0.058
    A           =   103.72;
    gamma_cal   =   5.2538;

% % % -- TO MAKE THE OPTIMAL TAX EQUAL TO 2, SET gamma_cal   =   1.54 ---
% % %     gamma_cal   =   1.54;
    
elseif rho==0.5
    A           =   102.17;
%     gamma_cal   =   2.1705;
    gamma_cal   =   5.2538;
elseif rho==-1
    A           =   104.69;
%     gamma_cal   =   15.5077;
    gamma_cal   =   5.2538;
end

GAMMA    =   [0 gamma_cal];
Fig_ind    =   1;


% % % -------------------- THE OPTIMAL TAX IS ZERO WHEN gamma=0 -----------
TAU_STAR   =   zeros(1,2);

% % % ---------------- THE VALUE OF THE PPOSITIVE EXTERNALITY -------------
gamma_tilde   =   GAMMA(2);

% % % ------------------ FIND THE OPTIMAL TAX BY BISECTION ----------------
tau_max   =   10;
tau_min   =   1e-8;
tau    =   (tau_max + tau_min)/2;

diff_tau   =   10;
while diff_tau>1e-6
  
   % % % --------------------- EQUILIBRIUM VARIABLES -------------------------
   [P,E,e1,e2,Y,D,C] = Eq_type_errors_sep_dam(A,lambda,rho,nu,p1,p2,gamma_tilde,tau);

   MC_Output = e1/(1-nu);
   MC_Energy_bill   =   -((p1*e1)/((1-rho)*(p1+tau))) + ((rho-nu)/((1-rho)*(1-nu)))*...
                        ((p1*e1 + p2*e2)/P)*((lambda*P/(p1+tau))^(1/(1-rho)));
   
   MC_Opt = MC_Output + MC_Energy_bill;       
        
   % % %  --------------------UPDATE tau WITH BISECTION ------------------

   MB_Opt = (2*gamma_tilde*(e1^2)/(1-rho))*...
            ((1/(p1+tau)) - ((rho-nu)/((1-nu)*P))*((lambda*P/(p1+tau))^(1/(1-rho))));
    
    diff_tax   =   MB_Opt   -  MC_Opt;
    
    if diff_tax<0
        tau_max=tau;
    else
        tau_min=tau;
    end
    
    tau    =   (tau_max + tau_min)/2;
    
    diff_tau   =   abs(diff_tax);  
    
    disp('Tax diff')
    disp(diff_tax)
    
end

%%% COMPUTE THE GAMMA THAT RESULTS IN 20 PERCENT DAMAGES AT A ZERO TAX RATE
[P_g,E_g,e1_g,e2_g,Y_g,D_g,C_g] = Eq_type_errors_sep_dam(A,lambda,rho,nu,p1,p2,0,0);
GAMMA_Cal   =   20/(e1_g^2);
disp('the gamma that gives 20% damages at a zero tax rate is')
disp(GAMMA_Cal)
clear P_g E_g e1_g e2_g Y_g D_g C_g


% % % -------------------- THE OPTIMAL TAX  ------------------------
TAU_STAR(2)   =   tau;

% % % ------------------- PRESENT SOME OUTPUT -----------------------
disp('Output when gamma>0')
disp('   (1-nu)Y     C       p1 +tau   ')
disp([(1-nu)*Y   C   p1+tau   ])
disp('')
disp('Y-C-p1*e1-p2*e2 - D')
disp(Y-C-p1*e1-p2*e2 - D)
disp('The optimal tax is:')
disp(TAU_STAR)


% % % - LOOP OVER TAX RATES BETWEEN ZERO AND TAU_STAR TO COMPUTE MB AND MC----

TAXES_1   =   -.50:+.01:TAU_STAR(2);
TAXES_2   =   TAU_STAR(2):+.01:1.5*TAU_STAR(2);
TAXES     =   [TAXES_1 TAXES_2];

MC_Output        =   zeros(2,length(TAXES));
MC_Energy_bill   =   zeros(2,length(TAXES));

MC      =   zeros(2,length(TAXES));
MB      =   zeros(2,length(TAXES));

P          =   zeros(2,length(TAXES));
e1         =   zeros(2,length(TAXES));
e2         =   zeros(2,length(TAXES));
Y          =   zeros(2,length(TAXES));
D          =   zeros(2,length(TAXES));
C          =   zeros(2,length(TAXES));

% % % ----------------- FOR THE OBJECTIVE --------------
OBJ_Priv   =   zeros(2,length(TAXES));
OBJ_Dam    =   zeros(2,length(TAXES));
e1_tau     =   zeros(2,length(TAXES));

for gamma_ind = 1:length(GAMMA)
    gamma_tilde   =   GAMMA(gamma_ind);
    for tax=1:length(TAXES)
        tau   =   TAXES(tax);
            % % % --------------------- EQUILIBRIUM VARIABLES -------------------------
       [P(gamma_ind,tax),E(gamma_ind,tax),e1(gamma_ind,tax),e2(gamma_ind,tax),...
           Y(gamma_ind,tax),D(gamma_ind,tax),C(gamma_ind,tax)] ...
           = Eq_type_errors_sep_dam(A,lambda,rho,nu,p1,p2,gamma_tilde,tau);

       MC_Output(gamma_ind,tax) = e1(gamma_ind,tax)/(1-nu);
       MC_Energy_bill(gamma_ind,tax)   =   -((p1*e1(gamma_ind,tax))/((1-rho)*(p1+tau))) + ((rho-nu)/((1-rho)*(1-nu)))*...
                        ((p1*e1(gamma_ind,tax) + p2*e2(gamma_ind,tax))/P(gamma_ind,tax))*...
                        ((lambda*P(gamma_ind,tax)/(p1+tau))^(1/(1-rho)));
                    
                    
       MC(gamma_ind,tax) = MC_Output(gamma_ind,tax) +...
                            MC_Energy_bill(gamma_ind,tax);

                        
       MB(gamma_ind,tax) = (2*gamma_tilde*(e1(gamma_ind,tax)^2)/(1-rho))*...
            ((1/(p1+tau)) - ((rho-nu)/((1-nu)*P(gamma_ind,tax)))*((lambda*P(gamma_ind,tax)/(p1+tau))^(1/(1-rho))));
        
        
% % % -------------------------- FOR THE OBJECTIVE ------------------------        
       OBJ_Priv(gamma_ind,tax)   =    Y(gamma_ind,tax) - p1*e1(gamma_ind,tax)- p2*e2(gamma_ind,tax);
       OBJ_Dam(gamma_ind,tax)    =    D(gamma_ind,tax);
       e1_tau(gamma_ind,tax)     =    e1(gamma_ind,tax);
        
                        
    end
    
end


%%%%%%%%%%%%%% PLOT RESULTS %%%%%%%%%%%%%%%%%



% % % --------------- COMPUTE THE COSTS OF THE POLICY MISTAKES ------------

% % % -------- THE COST OF OVERESTIMATING CLIMATE CHANGE (gamma=0)---------
L_OVER   =   C(1,1) - C(1,(length(TAXES_1)+1));

% % % ------- THE COST OF UNDERESTIMATING CLIMATE CHANGE (gamma>0)---------
L_UNDER   =   C(2,length(TAXES_1)+1) - C(2,1);


disp('The cost of underestimating climate change in units of C(opt_tax) is')
disp(100*(L_UNDER(end)/C(2,length(TAXES_1)+1)))

disp('The cost of overestimating climate change in units of C(opt_tax) is')
disp(100*(L_OVER(end)/C(1,1)))


% % % ---------------------- PLOT FOR TAXES BELOW ZERO --------------------
% % % ----- SET THE LOWEST TAX TO -0.5 TO AVOID NEGATIVE COONSUMPTION -----
Len   =   length(TAXES)-2;
if TAXES(1)<0
    
% % % ------------------ PLOT THE PARTS OF THE OBJECTIVE ------------------

% % % -------- PLACEMENT OF THE TEXT ---------------
     if TAXES_2(end)>=4*TAU_STAR(2)
         Text_ind_1   =  .9675;
     else
         Text_ind_1   =  1;
     end
     figure
     subplot(1,4,1)
     plot(TAXES(1:Len),OBJ_Priv(gamma_ind,1:Len),'-b','LineWidth',2)
     text(0,Text_ind_1*97.75,'{\itf}-{\itp_1}{\ite_1}-{\itp_2}{\ite_2}','FontSize',11)
     xlabel('{\tau}','FontSize',14)

     subplot(1,4,2)
     plot(TAXES(1:Len),e1_tau(2,1:Len),'-b','LineWidth',2)
     text(0,.4,'{\ite1}','FontSize',11)
     xlabel('{\tau}','FontSize',14)
     
     subplot(1,4,3)
     plot(TAXES(1:Len),-OBJ_Dam(2,1:Len),'-b','LineWidth',2)
     text(0,-70,'-{\itD} = -{\gamma}{\ite}_1^2','FontSize',11)
     xlabel('{\tau}','FontSize',14)
     
     subplot(1,4,4)
     plot(TAXES(1:Len),OBJ_Priv(gamma_ind,1:Len)-OBJ_Dam(2,1:Len),'-b','LineWidth',2)
     text(0,20.75,'{\itf}-{\itp_1}{\ite_1}-{\itp_2}{\ite_2}','FontSize',11)
     text(0,13.75,'-{\gamma}{\ite}_1^2','FontSize',11)
     xlabel('{\tau}','FontSize',14)

     
%      text(1,10,'{\itD} = {\gamma}{\ite}_1^2','FontSize',12)
end

%%%%%%%%%%%%%%%% PLOT FOR DIFFERENT ELASTICITIES %%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%% PLOT FOR DIFFERENT ELASTICITIES %%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%% PLOT FOR DIFFERENT ELASTICITIES %%%%%%%%%%%%%%%%%

